@@ -7,13 +7,11 @@ towncrier, a builder for your news files.
 
 from __future__ import annotations
 
-from incremental import Version
-
 
 __all__ = ["__version__"]
 
 
-def __getattr__(name: str) -> Version:
+def __getattr__(name: str) -> str:
     if name != "__version__":
         raise AttributeError(f"module {__name__} has no attribute {name}")
 
